==> core_models-0.1.0.gem: app/controllers/core_models/people_and_companies/banks_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class PeopleAndCompanies::BanksController < CoreModelsController
    # GET /people_and_companies/banks
    # GET /people_and_companies/banks.json
    def index
      @people_and_companies_banks = PeopleAndCompanies::Bank.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @people_and_companies_banks }
      end
    end

    # GET /people_and_companies/banks/1
    # GET /people_and_companies/banks/1.json
    def show
      @people_and_companies_bank = PeopleAndCompanies::Bank.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @people_and_companies_bank }
      end
    end

    # GET /people_and_companies/banks/new
    # GET /people_and_companies/banks/new.json
    def new
      @people_and_companies_bank = PeopleAndCompanies::Bank.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @people_and_companies_bank }
      end
    end

    # GET /people_and_companies/banks/1/edit
    def edit
      @people_and_companies_bank = PeopleAndCompanies::Bank.find(params[:id])
    end

    # POST /people_and_companies/banks
    # POST /people_and_companies/banks.json
    def create
      @people_and_companies_bank = PeopleAndCompanies::Bank.new(params[:people_and_companies_bank])

      respond_to do |format|
        if @people_and_companies_bank.save
          format.html { redirect_to @people_and_companies_bank, :notice => 'Bank was successfully created.' }
          format.json { render :json => @people_and_companies_bank, :status => :created, :location => @people_and_companies_bank }
        else
          format.html { render :action => "new" }
          format.json { render :json => @people_and_companies_bank.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /people_and_companies/banks/1
    # PUT /people_and_companies/banks/1.json
    def update
      @people_and_companies_bank = PeopleAndCompanies::Bank.find(params[:id])

      respond_to do |format|
        if @people_and_companies_bank.update_attributes(params[:people_and_companies_bank])
          format.html { redirect_to @people_and_companies_bank, :notice => 'Bank was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @people_and_companies_bank.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /people_and_companies/banks/1
    # DELETE /people_and_companies/banks/1.json
    def destroy
      @people_and_companies_bank = PeopleAndCompanies::Bank.find(params[:id])
      @people_and_companies_bank.destroy

      respond_to do |format|
        format.html { redirect_to people_and_companies_banks_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/people_and_companies/banks_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class PeopleAndCompanies::BanksController < CoreModelsController
    # GET /people_and_companies/banks
    # GET /people_and_companies/banks.json
    def index
      @people_and_companies_banks = PeopleAndCompanies::Bank.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @people_and_companies_banks }
      end
    end

    # GET /people_and_companies/banks/1
    # GET /people_and_companies/banks/1.json
    def show
      @people_and_companies_bank = PeopleAndCompanies::Bank.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @people_and_companies_bank }
      end
    end

    # GET /people_and_companies/banks/new
    # GET /people_and_companies/banks/new.json
    def new
      @people_and_companies_bank = PeopleAndCompanies::Bank.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @people_and_companies_bank }
      end
    end

    # GET /people_and_companies/banks/1/edit
    def edit
      @people_and_companies_bank = PeopleAndCompanies::Bank.find(params[:id])
    end

    # POST /people_and_companies/banks
    # POST /people_and_companies/banks.json
    def create
      @people_and_companies_bank = PeopleAndCompanies::Bank.new(params[:people_and_companies_bank])

      respond_to do |format|
        if @people_and_companies_bank.save
          format.html { redirect_to @people_and_companies_bank, :notice => 'Bank was successfully created.' }
          format.json { render :json => @people_and_companies_bank, :status => :created, :location => @people_and_companies_bank }
        else
          format.html { render :action => "new" }
          format.json { render :json => @people_and_companies_bank.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /people_and_companies/banks/1
    # PUT /people_and_companies/banks/1.json
    def update
      @people_and_companies_bank = PeopleAndCompanies::Bank.find(params[:id])

      respond_to do |format|
        if @people_and_companies_bank.update(params[:people_and_companies_bank])
          format.html { redirect_to @people_and_companies_bank, :notice => 'Bank was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @people_and_companies_bank.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /people_and_companies/banks/1
    # DELETE /people_and_companies/banks/1.json
    def destroy
      @people_and_companies_bank = PeopleAndCompanies::Bank.find(params[:id])
      @people_and_companies_bank.destroy

      respond_to do |format|
        format.html { redirect_to people_and_companies_banks_url }
        format.json { head :no_content }
      end
    end
  end
end
